@@ -346,23 +346,26 @@ image_quantize_png_quantize (image_quantize_t * iq)
 
     png_color png_colours[256];
 
-    /* Quantize the buffer. */
+    /* Check the inputs. */
 
     error = liq_invalid_attr (iq->attr);
     if (error != LIQ_OK) {
-	image_quantize_error (iq, error, "invalid liq_attr");
+	image_quantize_error (iq, error, "liq_invalid_attr");
     }
     error = liq_invalid_image (iq->image);
     if (error != LIQ_OK) {
-	image_quantize_error (iq, error, "invalid liq_image");
+	image_quantize_error (iq, error, "liq_invalid_image");
     }
+
+    /* Quantize the buffer. */
+
     error = liq_quantize_image_2 (iq->attr, iq->image, & iq->result);
     if (error != LIQ_OK) {
-	image_quantize_error (iq, error, "liq_quantize_image failed");
+	image_quantize_error (iq, error, "liq_quantize_image_2 failed");
     }
 
     if (! iq->result) {
-	image_quantize_perl_error (iq, "liq_quantize_image failed");
+	image_quantize_perl_error (iq, "liq_quantize_image_2 failed but returned no error code");
     }
     IQGET;
 
